@@ -2,7 +2,7 @@
 # See also LICENSE.txt
 """Install the reference package."""
 
-import zope.app.generations.utility
+import zope.generations.utility
 
 import gocept.reference.manager
 import gocept.reference.interfaces
@@ -10,7 +10,7 @@ import gocept.reference.interfaces
 
 def evolve(context):
     # Install the reference manager utility into the root site.
-    root = zope.app.generations.utility.getRootFolder(context)
+    root = zope.generations.utility.getRootFolder(context)
     sm = root.getSiteManager()
     if 'gocept.reference' not in sm:
         sm['gocept.reference'] = gocept.reference.manager.ReferenceManager()
